==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/Ping/src/com/clustercontrol/ping/bean/MonitorPingInfo.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.ping.bean;

import com.clustercontrol.bean.PingRunCountConstant;
import com.clustercontrol.bean.PingRunIntervalConstant;
import com.clustercontrol.monitor.run.bean.MonitorCheckInfo;

/**
 * pingƻ󥯥饹Ǥ
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class MonitorPingInfo extends MonitorCheckInfo
{
	
	/** ¹Բ */
	protected java.lang.Integer runCount = Integer.valueOf(PingRunCountConstant.TYPE_COUNT_01);
	/** ¹Դֳ֡á */
	protected java.lang.Integer runInterval = Integer.valueOf(PingRunIntervalConstant.TYPE_SEC_01);
	/** ॢȡʥߥá */
	protected java.lang.Integer timeout = 1000;

   public MonitorPingInfo()
   {
   }

   public java.lang.Integer getRunCount()
   {
      return this.runCount;
   }
   public void setRunCount( java.lang.Integer runCount )
   {
      this.runCount = runCount;
   }

   public java.lang.Integer getRunInterval()
   {
      return this.runInterval;
   }
   public void setRunInterval( java.lang.Integer runInterval )
   {
      this.runInterval = runInterval;
   }
   
   public java.lang.Integer getTimeout()
   {
      return this.timeout;
   }
   public void setTimeout( java.lang.Integer timeout )
   {
      this.timeout = timeout;
   }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/Ping/src/com/clustercontrol/ping/bean/MonitorPingInfo.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.ping.bean;

import com.clustercontrol.bean.PingRunCountConstant;
import com.clustercontrol.bean.PingRunIntervalConstant;
import com.clustercontrol.monitor.run.bean.MonitorCheckInfo;

/**
 * ping監視情報クラスです。
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class MonitorPingInfo extends MonitorCheckInfo
{
	
	/** 実行回数 */
	protected java.lang.Integer runCount = Integer.valueOf(PingRunCountConstant.TYPE_COUNT_01);
	/** 実行間隔（秒） */
	protected java.lang.Integer runInterval = Integer.valueOf(PingRunIntervalConstant.TYPE_SEC_01);
	/** タイムアウト（ミリ秒） */
	protected java.lang.Integer timeout = 1000;

   public MonitorPingInfo()
   {
   }

   public java.lang.Integer getRunCount()
   {
      return this.runCount;
   }
   public void setRunCount( java.lang.Integer runCount )
   {
      this.runCount = runCount;
   }

   public java.lang.Integer getRunInterval()
   {
      return this.runInterval;
   }
   public void setRunInterval( java.lang.Integer runInterval )
   {
      this.runInterval = runInterval;
   }
   
   public java.lang.Integer getTimeout()
   {
      return this.timeout;
   }
   public void setTimeout( java.lang.Integer timeout )
   {
      this.timeout = timeout;
   }
}
